# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from .. import Provider as LoremProvider


class Provider(LoremProvider):
    word_list = (
        'алььтыра', 'дэлььынётё', 'вэртырэм', 'вэрыар', 'ты', 'рэгяонэ',
        'црял', 'квюальизквюэ', 'квюоджё', 'зюаз', 'конгуы', 'антеопам',
        'прё', 'этёам', 'форынчйбюж', 'альиквуандо', 'зэнтынтиаэ', 'хёз',
        'адепйжкйнг', 'ыюм', 'льаборэж', 'вим', 'фабулаз', 'нэ', 'толлйт',
        'эож', 'ажжюм', 'лыгимуз', 'пэртинакёа', 'видишчы', 'рэпудёандаэ',
        'еюж', 'бонорюм', 'про', 'но', 'анкилльаы', 'доктюж', 'адипижкй',
        'зигнёфэрумквюы', 'дэлььиката', 'мютат', 'амэт', 'едквюэ', 'апыирёан',
        'мэя', 'латины', 'ед', 'дытракжйт', 'констятюам', 'ку', 'дольор',
        'игнота', 'льаорыыт', 'хэндрэрет', 'магна', 'мэль', 'дыфяниэбаж',
        'дэльэнйт', 'агам', 'эффикеэнди', 'дикунт', 'хабэо', 'ыт', 'ёужто',
        'долорэж', 'ипзум', 'аппэтырэ', 'ючю', 'брутэ', 'долорэм',
        'интылльэгэбат', 'вёжи', 'эвэртё', 'татион', 'зймюл', 'эи',
        'юрбанйтаж', 'кибо', 'прима', 'ад', 'попюльо', 'вирйз', 'незл',
        'тальэ', 'ан', 'жолюм', 'лебыр', 'эюрйпйдяч', 'вёртюты', 'зыд',
        'пауло', 'омныз', 'хонэзтатёз', 'тебиквюэ', 'шэа', 'оффекйяж', 'ат',
        'рыквюы', 'декат', 'торквюатоз', 'дюиж', 'номинатй', 'жкаывола',
        'ведят', 'аккузата', 'пхйложопхяа', 'аппарэат', 'порро', 'эю',
        'эрюдитя', 'адмодум', 'эррорибуз', 'чэнзэрет', 'мэльёуз', 'бландит',
        'молыжтйаы', 'пошжим', 'тамквюам', 'ажжынтиор', 'вяш', 'ывыртятюр',
        'эпикюре', 'квуёдам', 'граэкйж', 'конжтетуто', 'такематыш', 'мацим',
        'шынчебюз', 'витюпэраторебуз', 'дытыррюизщэт', 'граэко', 'граэки',
        'щуавятатэ', 'пырикульа', 'квюандо', 'факёльиси', 'дычэрунт', 'кюм',
        'аккюжамюз', 'омнэжквюы', 'экз', 'индоктум', 'рэктэквуэ', 'дектаж',
        'фюгит', 'хабымуч', 'фалля', 'нонумй', 'апэриам', 'июварыт', 'квуй',
        'мыис', 'дежпютатионй', 'мыдиокрым', 'ылоквюэнтиам', 'нюлльам', 'ут',
        'аугюэ', 'ыам', 'фырре', 'азжюывырит', 'квуым', 'йн', 'ножтро',
        'зючкёпит', 'конкыптам', 'майыжтатйж', 'дуо', 'ыт', 'элыктрам',
        'ёнэрмйщ', 'ыпикурэи', 'ыёюз', 'инимёкюж', 'шапэрэт', 'выро',
        'либриз', 'кевёбюж', 'эа', 'коммюны', 'лэгыры', 'рыпрэхэндунт',
        'дёзсэнтёаш', 'лаборамюз', 'элитр', 'чадипжкёнг', 'мёнём', 'нык',
        'мыа', 'тота', 'квюот', 'ратионебюж', 'пырфэкто', 'факэр', 'пэрчёус',
        'ёнанй', 'кончэтытюр', 'одео', 'зкрипторэм', 'чонэт', 'факилиз',
        'жэмпэр', 'атоморюм', 'эжт', 'дылыктуч', 'тинкидюнт', 'аэквюы',
        'глориатюр', 'пэркйпет', 'модо', 'жят', 'эзшэ', 'хаж', 'аюдирэ',
        'вокынт', 'векж', 'квюоджёныглэгэнтур', 'луптатум', 'мюндй',
        'опортэры', 'дэлььякатезшимя', 'квюиж', 'витюпырата', 'вэл',
        'ыльигэнди', 'янтэрэсщэт', 'оффэндйт', 'нихйл', 'квюаэчтио', 'пэр',
        'квюо', 'пырикюлёз', 'нам', 'атквюе'
    )
